@@ -120,7 +120,6 @@ class Run():
             _data = json.load(f)
             f.close()
         if _data:
-            print(_data)
             _remote_path = _data['website']['siteUrl']
             config_user_id = _data['website']['user']['_id']
             config_lab_id = _data['website']['lab']['_id']
@@ -156,11 +155,11 @@ class Run():
 
         # self.user_token = user_token
         if config_token:
-            print('config_token')
+            print('using config_token')
             self.user_token = config_token
         elif env_token:
-            print('env_token')
-            self.user_token = config_token
+            print('using env_token')
+            self.user_token = env_token
         else:
             self.user_token = user_token
 
@@ -438,7 +437,6 @@ class Run():
                         print('Error uploading file ', file)
         if self.remote_path:
             tp = int(time.time())
-            print(prefixes)
             json_struct = {
                 "metadata": self.metadata,
                 "files": prefixes,
